pub struct DebtRecoveryItem {
pub recovery_amount: Option<Box<Currency>>,
pub original_amount: Option<Box<Currency>>,
pub group_begin_date: Option<String>,
pub group_end_date: Option<String>,
}Expand description
DebtRecoveryItem : An item of a debt payment or debt adjustment.
Fields
recovery_amount: Option<Box<Currency>>original_amount: Option<Box<Currency>>group_begin_date: Option<String>group_end_date: Option<String>Implementations
sourceimpl DebtRecoveryItem
impl DebtRecoveryItem
sourcepub fn new() -> DebtRecoveryItem
pub fn new() -> DebtRecoveryItem
An item of a debt payment or debt adjustment.